/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<aboutcomponent_p.h>)
#  include <aboutcomponent_p.h>
#endif
#if __has_include(<filehelper_p.h>)
#  include <filehelper_p.h>
#endif
#if __has_include(<passwordhealth.h>)
#  include <passwordhealth.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigamiaddons_formcard()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AboutComponent>("org.kde.kirigamiaddons.formcard", 1);
    qmlRegisterTypesAndRevisions<FileHelper>("org.kde.kirigamiaddons.formcard", 1);
    qmlRegisterTypesAndRevisions<PasswordHealth>("org.kde.kirigamiaddons.formcard", 1);
    qmlRegisterEnum<PasswordHealth::Quality>("PasswordHealth::Quality");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigamiaddons.formcard", 1, 0);
}

static const QQmlModuleRegistration orgkdekirigamiaddonsformcardRegistration("org.kde.kirigamiaddons.formcard", qml_register_types_org_kde_kirigamiaddons_formcard);
