/****************************************************************************
** Meta object code from reading C++ file 'infinitecalendarviewmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-addons-1.13.1/src/dateandtime/infinitecalendarviewmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'infinitecalendarviewmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25InfiniteCalendarViewModelE_t {};
} // unnamed namespace

template <> constexpr inline auto InfiniteCalendarViewModel::qt_create_metaobjectdata<qt_meta_tag_ZN25InfiniteCalendarViewModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InfiniteCalendarViewModel",
        "QML.Element",
        "auto",
        "datesToAddChanged",
        "",
        "scaleChanged",
        "currentDateChanged",
        "minimumDateChanged",
        "maximumDateChanged",
        "addDates",
        "atEnd",
        "startFrom",
        "datesToAdd",
        "scale",
        "currentDate",
        "minimumDate",
        "maximumDate",
        "Scale",
        "WeekScale",
        "MonthScale",
        "YearScale",
        "DecadeScale",
        "Roles",
        "StartDateRole",
        "FirstDayOfMonthRole",
        "SelectedMonthRole",
        "SelectedYearRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'datesToAddChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDateChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumDateChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumDateChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'addDates'
        QtMocHelpers::MethodData<void(bool, const QDateTime &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::QDateTime, 11 },
        }}),
        // Method 'addDates'
        QtMocHelpers::MethodData<void(bool)>(9, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'datesToAdd'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'scale'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'currentDate'
        QtMocHelpers::PropertyData<QDateTime>(14, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'minimumDate'
        QtMocHelpers::PropertyData<QDateTime>(15, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'maximumDate'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Scale'
        QtMocHelpers::EnumData<enum Scale>(17, 17, QMC::EnumFlags{}).add({
            {   18, Scale::WeekScale },
            {   19, Scale::MonthScale },
            {   20, Scale::YearScale },
            {   21, Scale::DecadeScale },
        }),
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(22, 22, QMC::EnumFlags{}).add({
            {   23, Roles::StartDateRole },
            {   24, Roles::FirstDayOfMonthRole },
            {   25, Roles::SelectedMonthRole },
            {   26, Roles::SelectedYearRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<InfiniteCalendarViewModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InfiniteCalendarViewModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25InfiniteCalendarViewModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25InfiniteCalendarViewModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25InfiniteCalendarViewModelE_t>.metaTypes,
    nullptr
} };

void InfiniteCalendarViewModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InfiniteCalendarViewModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->datesToAddChanged(); break;
        case 1: _t->scaleChanged(); break;
        case 2: _t->currentDateChanged(); break;
        case 3: _t->minimumDateChanged(); break;
        case 4: _t->maximumDateChanged(); break;
        case 5: _t->addDates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 6: _t->addDates((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InfiniteCalendarViewModel::*)()>(_a, &InfiniteCalendarViewModel::datesToAddChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfiniteCalendarViewModel::*)()>(_a, &InfiniteCalendarViewModel::scaleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfiniteCalendarViewModel::*)()>(_a, &InfiniteCalendarViewModel::currentDateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfiniteCalendarViewModel::*)()>(_a, &InfiniteCalendarViewModel::minimumDateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InfiniteCalendarViewModel::*)()>(_a, &InfiniteCalendarViewModel::maximumDateChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->datesToAdd(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->scale(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->currentDate(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->minimumDate(); break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->maximumDate(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDatesToAdd(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setScale(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setCurrentDate(*reinterpret_cast<QDateTime*>(_v)); break;
        case 3: _t->setMinimumDate(*reinterpret_cast<QDateTime*>(_v)); break;
        case 4: _t->setMaximumDate(*reinterpret_cast<QDateTime*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InfiniteCalendarViewModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InfiniteCalendarViewModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25InfiniteCalendarViewModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int InfiniteCalendarViewModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void InfiniteCalendarViewModel::datesToAddChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InfiniteCalendarViewModel::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InfiniteCalendarViewModel::currentDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void InfiniteCalendarViewModel::minimumDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InfiniteCalendarViewModel::maximumDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
