/****************************************************************************
** Meta object code from reading C++ file 'abstractkirigamiapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-addons-1.13.1/src/statefulapplication/abstractkirigamiapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractkirigamiapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27AbstractKirigamiApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractKirigamiApplication::qt_create_metaobjectdata<qt_meta_tag_ZN27AbstractKirigamiApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractKirigamiApplication",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Abstract class",
        "openAboutPage",
        "",
        "openAboutKDEPage",
        "openKCommandBarAction",
        "shortcutsEditorAction",
        "configurationViewChanged",
        "action",
        "QAction*",
        "actionName",
        "actionsModel",
        "QSortFilterProxyModel*",
        "shortcutsModel",
        "QAbstractListModel*",
        "configurationView"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openAboutPage'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openAboutKDEPage'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openKCommandBarAction'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shortcutsEditorAction'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationViewChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'action'
        QtMocHelpers::MethodData<QAction *(const QString &)>(13, 8, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'actionsModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shortcutsModel'
        QtMocHelpers::PropertyData<QAbstractListModel*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'configurationView'
        QtMocHelpers::PropertyData<QObject*>(20, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AbstractKirigamiApplication, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AbstractKirigamiApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AbstractKirigamiApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AbstractKirigamiApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27AbstractKirigamiApplicationE_t>.metaTypes,
    nullptr
} };

void AbstractKirigamiApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractKirigamiApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openAboutPage(); break;
        case 1: _t->openAboutKDEPage(); break;
        case 2: _t->openKCommandBarAction(); break;
        case 3: _t->shortcutsEditorAction(); break;
        case 4: _t->configurationViewChanged(); break;
        case 5: { QAction* _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractKirigamiApplication::*)()>(_a, &AbstractKirigamiApplication::openAboutPage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractKirigamiApplication::*)()>(_a, &AbstractKirigamiApplication::openAboutKDEPage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractKirigamiApplication::*)()>(_a, &AbstractKirigamiApplication::openKCommandBarAction, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractKirigamiApplication::*)()>(_a, &AbstractKirigamiApplication::shortcutsEditorAction, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractKirigamiApplication::*)()>(_a, &AbstractKirigamiApplication::configurationViewChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractListModel* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSortFilterProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->actionsModel(); break;
        case 1: *reinterpret_cast<QAbstractListModel**>(_v) = _t->shortcutsModel(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->configurationView(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setConfigurationView(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractKirigamiApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractKirigamiApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AbstractKirigamiApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractKirigamiApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void AbstractKirigamiApplication::openAboutPage()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractKirigamiApplication::openAboutKDEPage()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractKirigamiApplication::openKCommandBarAction()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractKirigamiApplication::shortcutsEditorAction()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractKirigamiApplication::configurationViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
