/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x15,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x87,0x6,0x5d,0x10,0x0,0x96,0x56,0x41,0x1d,0x50,0x75,0xe,
  0xf,0x92,0x5c,0xe,0xa5,0xb4,0xfb,0xe4,0xbe,0x74,0x59,0x50,0x3d,0x22,0x52,0x1c,
  0x8a,0xc2,0x49,0xf1,0x8a,0x4d,0xcc,0x76,0x6b,0xd,0x38,0x0,0x3a,0x0,0x38,0x0,
  0xaf,0xb9,0x4c,0xd4,0x17,0x5e,0xa5,0x3a,0xff,0xa8,0x54,0x2a,0xe,0xf9,0x3d,0x6c,
  0xb,0x6a,0xc8,0xbd,0x4f,0xf5,0xc3,0xcb,0xaa,0x46,0x41,0xaf,0xcc,0xf1,0x27,0xde,
  0xf6,0xa4,0xe3,0x72,0xde,0x97,0xe8,0x71,0x67,0xe2,0x3a,0x64,0xeb,0x3b,0x45,0x9a,
  0x53,0xc4,0xbc,0x21,0x6d,0x55,0xb6,0xb,0xee,0x3,0x83,0xf3,0x46,0xfc,0x42,0xff,
  0xa7,0xc,0x1f,0x10,0x20,0xa,0x40,0x7,0x3,0xe3,0xab,0xb6,0xc,0x1e,0x49,0x92,
  0x24,0xa9,0xb9,0x8c,0xf4,0x19,0x49,0x0,0xb9,0x5e,0xd4,0xa9,0x47,0xa6,0x4d,0xd5,
  0xed,0x27,0xa3,0x3e,0xe6,0x7b,0x56,0x6e,0xca,0xf5,0x52,0xef,0xf5,0x92,0x95,0xd2,
  0x7c,0x2,0xe9,0xbd,0x79,0xf,0x1f,0xbc,0x8d,0x44,0x55,0x28,0x2f,0x3e,0x77,0x21,
  0xd7,0x13,0xae,0xd9,0xba,0x2d,0xc2,0xfb,0xd1,0x91,0x52,0x49,0x72,0xd5,0xce,0xa6,
  0x85,0x4,0x75,0x3b,0xd1,0x47,0x3,0xa7,0x9,0x6d,0x71,0x3d,0x2d,0xc5,0xb0,0x6e,
  0xb8,0x86,0x74,0x2c,0x70,0xff,0x57,0x84,0x4d,0x7,0xcf,0x33,0xad,0xad,0x20,0xf,
  0x79,0xbf,0x4c,0xe1,0x7e,0x6d,0x8c,0xf7,0x49,0x9a,0x75,0xaa,0x1b,0x4e,0x7f,0xf1,
  0xac,0xdc,0x6b,0xd1,0x50,0x7d,0x80,0x59,0xbf,0x1b,0x5e,0xea,0x39,0x3a,0xe1,0x5e,
  0x89,0xf7,0x2f,0x49,0x6f,0x62,0x84,0xe1,0x7b,0xea,0xc0,0xe8,0xc2,0x96,0x4d,0x17,
  0x11,0x80,0x88,0xa8,0x61,0x9a,0x40,0x8c,0x46,0x9a,0x24,0x85,0xf6,0xc,0x30,0x44,
  0x48,0xb9,0x4d,0x7,0x41,0x14,0xa3,0x88,0xa3,0x8c,0x10,0x66,0x44,0x9c,0x24,0xfb,
  0x71,0x3f,0xbe,0x5c,0xb6,0x53,0x4b,0xb5,0x29,0xc9,0xa7,0xb0,0x52,0x48,0x91,0x99,
  0xe4,0xbe,0xbe,0x6e,0x14,0x6a,0x2c,0x94,0x82,0x4a,0xce,0x57,0xb8,0xd9,0x48,0xee,
  0xf2,0x7d,0xca,0xf2,0x35,0xed,0x75,0xd6,0xb4,0x6a,0x2e,0x4f,0xb5,0xff,0xf8,0x2a,
  0x11,0xaf,0x66,0x72,0x77,0x8a,0xbf,0x7e,0x4a,0x62,0xa6,0xac,0x32,0xec,0x4a,0x58,
  0x2a,0x87,0xdf,0xda,0x4f,0x9b,0x7f,0x81,0xe5,0x6a,0xe7,0x7e,0x50,0x76,0xf0,0x4b,
  0x62,0xdf,0x88,0x98,0x8c,0x7d,0xf1,0xcc,0x9f,0x6,0x71,0xb1,0xad,0x71,0x7c,0x97,
  0x3d,0x87,0x10,0xd2,0x1f,0x95,0x47,0x52,0xcb,0x58,0x68,0x44,0x29,0xdf,0x73,0xcd,
  0x8a,0xa3,0xb1,0x49,0x37,0x75,0x3c,0x1c,0xf3,0x7a,0x9d,0xdd,0x9f,0x22,0x80,0x0,
  0xe,0x2a,0xc7,0x8b,0xa5,0xf9,0x72,0xbe,0x72,0x5d,0xaa,0xd1,0xa4,0x37,0xa7,0xd8,
  0x56,0x8f,0x7c,0xcf,0x20,0x38,0x6c,0xe4,0xd1,0x76,0xf3,0xac,0xf,0x63,0x82,0x4a,
  0x44,0x48,0x3d,0x4e,0xd4,0x41,0x22,0xc2,0xf5,0x2d,0x61,0x94,0x46,0x5e,0x1,0xed,
  0x97,0xa,0x8e,0x1,0xa3,0xa7,0x77,0x1c,0x18,0x2,0x44,0x14,0x4d,0xd5,0xac,0xbc,
  0x53,0xf9,0xad,0x34,0xdd,0xc3,0x96,0x5b,0x2b,0x3e,0x71,0xc,0x5d,0x8b,0xda,0x8d,
  0x2d,0x17,0x53,0xa6,0x78,0xa1,0x20,0xf8,0x80,0x15,0x4d,0x31,0x2,0x11,0xa6,0xa8,
  0x72,0x31,0xae,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // kirigamiaddons
  0x0,0xe,
  0xe,0x65,0x2,0xb3,
  0x0,0x6b,
  0x0,0x69,0x0,0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,0x6d,0x0,0x69,0x0,0x61,0x0,0x64,0x0,0x64,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // formcard
  0x0,0x8,
  0x6,0x93,0x95,0x24,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x63,0x0,0x61,0x0,0x72,0x0,0x64,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml/org/kde/kirigamiaddons
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml/org/kde/kirigamiaddons/formcard
  0x0,0x0,0x0,0x50,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,
  // :/qt/qml/org/kde/kirigamiaddons/formcard/qmldir
  0x0,0x0,0x0,0x66,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x80,0xee,0x26,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigamiaddons_formcard)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigamiaddons_formcard)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigamiaddons_formcard)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigamiaddons_formcard)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kirigamiaddons_formcard)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kirigamiaddons_formcard)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
