/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<defaultapplication.h>)
#  include <defaultapplication.h>
#endif
#if __has_include(<helper.h>)
#  include <helper.h>
#endif
#if __has_include(<keysequencehelper.h>)
#  include <keysequencehelper.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigamiaddons_statefulapp_private()
{
    qmlRegisterModule("org.kde.kirigamiaddons.statefulapp.private", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DefaultKirigamiApplication>("org.kde.kirigamiaddons.statefulapp.private", 254);
    qmlRegisterTypesAndRevisions<Helper>("org.kde.kirigamiaddons.statefulapp.private", 254);
    QMetaType::fromType<KKeySequenceRecorder *>().id();
    qmlRegisterEnum<KKeySequenceRecorder::Patterns>("KKeySequenceRecorder::Patterns");
    qmlRegisterEnum<KKeySequenceRecorder::Pattern>("KKeySequenceRecorder::Pattern");
    qmlRegisterTypesAndRevisions<KeySequenceHelper>("org.kde.kirigamiaddons.statefulapp.private", 254);
    qmlRegisterEnum<KeySequenceHelper::ShortcutTypes>("KeySequenceHelper::ShortcutTypes");
    qmlRegisterEnum<KeySequenceHelper::ShortcutType>("KeySequenceHelper::ShortcutType");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigamiaddons.statefulapp.private", 254, 254);
}

static const QQmlModuleRegistration orgkdekirigamiaddonsstatefulappprivateRegistration("org.kde.kirigamiaddons.statefulapp.private", qml_register_types_org_kde_kirigamiaddons_statefulapp_private);
