/****************************************************************************
** Meta object code from reading C++ file 'onboardingcontroller_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-addons-1.13.1/src/onboarding/onboardingcontroller_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'onboardingcontroller_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20OnboardingControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto OnboardingController::qt_create_metaobjectdata<qt_meta_tag_ZN20OnboardingControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OnboardingController",
        "activeChanged",
        "",
        "sourceChanged",
        "activeGroupChanged",
        "currentIndexChanged",
        "currentItemChanged",
        "currentTextChanged",
        "additionalDataComponentChanged",
        "geometryChanged",
        "paddingChanged",
        "blurChanged",
        "blurMaxChanged",
        "navigationChanged",
        "aboutToStart",
        "finished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeGroupChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentItemChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'additionalDataComponentChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paddingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurMaxChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToStart'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OnboardingController, qt_meta_tag_ZN20OnboardingControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OnboardingController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OnboardingControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OnboardingControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20OnboardingControllerE_t>.metaTypes,
    nullptr
} };

void OnboardingController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OnboardingController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged(); break;
        case 1: _t->sourceChanged(); break;
        case 2: _t->activeGroupChanged(); break;
        case 3: _t->currentIndexChanged(); break;
        case 4: _t->currentItemChanged(); break;
        case 5: _t->currentTextChanged(); break;
        case 6: _t->additionalDataComponentChanged(); break;
        case 7: _t->geometryChanged(); break;
        case 8: _t->paddingChanged(); break;
        case 9: _t->blurChanged(); break;
        case 10: _t->blurMaxChanged(); break;
        case 11: _t->navigationChanged(); break;
        case 12: _t->aboutToStart(); break;
        case 13: _t->finished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::sourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::activeGroupChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::currentIndexChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::currentItemChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::currentTextChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::additionalDataComponentChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::geometryChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::paddingChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::blurChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::blurMaxChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::navigationChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::aboutToStart, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (OnboardingController::*)()>(_a, &OnboardingController::finished, 13))
            return;
    }
}

const QMetaObject *OnboardingController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OnboardingController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OnboardingControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OnboardingController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void OnboardingController::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OnboardingController::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OnboardingController::activeGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OnboardingController::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OnboardingController::currentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OnboardingController::currentTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OnboardingController::additionalDataComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OnboardingController::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void OnboardingController::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void OnboardingController::blurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void OnboardingController::blurMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void OnboardingController::navigationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void OnboardingController::aboutToStart()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void OnboardingController::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
