/****************************************************************************
** Meta object code from reading C++ file 'onboarding_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-addons-1.13.1/src/onboarding/onboarding_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'onboarding_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10OnboardingE_t {};
} // unnamed namespace

template <> constexpr inline auto Onboarding::qt_create_metaobjectdata<qt_meta_tag_ZN10OnboardingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Onboarding",
        "QML.Element",
        "auto",
        "QML.Attached",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached Property",
        "isSourceChanged",
        "",
        "sourceGroupsChanged",
        "groupsChanged",
        "textsChanged",
        "additionalDataChanged",
        "enabledChanged",
        "aboutToShow",
        "hide",
        "activeChanged",
        "sourceChanged",
        "currentIndexChanged",
        "currentItemChanged",
        "currentTextChanged",
        "additionalDataComponentChanged",
        "geometryChanged",
        "paddingChanged",
        "blurChanged",
        "blurMaxChanged",
        "navigationChanged",
        "aboutToStart",
        "finished",
        "start",
        "group",
        "stop",
        "next",
        "previous",
        "isSource",
        "sourceGroups",
        "groups",
        "texts",
        "additionalData",
        "QVariantMap",
        "enabled",
        "target",
        "QQuickItem*",
        "sequence",
        "active",
        "source",
        "currentIndex",
        "currentItem",
        "Onboarding*",
        "currentText",
        "additionalDataComponent",
        "QQmlComponent*",
        "x",
        "y",
        "width",
        "height",
        "padding",
        "blur",
        "blurMax",
        "hasNextItem",
        "hasPreviousItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isSourceChanged'
        QtMocHelpers::SignalData<void()>(8, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceGroupsChanged'
        QtMocHelpers::SignalData<void()>(10, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupsChanged'
        QtMocHelpers::SignalData<void()>(11, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textsChanged'
        QtMocHelpers::SignalData<void()>(12, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'additionalDataChanged'
        QtMocHelpers::SignalData<void()>(13, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(14, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToShow'
        QtMocHelpers::SignalData<void()>(15, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hide'
        QtMocHelpers::SignalData<void()>(16, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(17, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(18, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(19, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentItemChanged'
        QtMocHelpers::SignalData<void()>(20, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTextChanged'
        QtMocHelpers::SignalData<void()>(21, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'additionalDataComponentChanged'
        QtMocHelpers::SignalData<void()>(22, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(23, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paddingChanged'
        QtMocHelpers::SignalData<void()>(24, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurChanged'
        QtMocHelpers::SignalData<void()>(25, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurMaxChanged'
        QtMocHelpers::SignalData<void()>(26, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationChanged'
        QtMocHelpers::SignalData<void()>(27, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToStart'
        QtMocHelpers::SignalData<void()>(28, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(29, 9, QMC::AccessPublic, QMetaType::Void),
        // Method 'start'
        QtMocHelpers::MethodData<void()>(30, 9, QMC::AccessPublic, QMetaType::Void),
        // Method 'start'
        QtMocHelpers::MethodData<void(const QString &)>(30, 9, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(32, 9, QMC::AccessPublic, QMetaType::Void),
        // Method 'next'
        QtMocHelpers::MethodData<void()>(33, 9, QMC::AccessPublic, QMetaType::Void),
        // Method 'previous'
        QtMocHelpers::MethodData<void()>(34, 9, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isSource'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'sourceGroups'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'groups'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'texts'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'additionalData'
        QtMocHelpers::PropertyData<QVariantMap>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'target'
        QtMocHelpers::PropertyData<QQuickItem*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sequence'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'source'
        QtMocHelpers::PropertyData<QQuickItem*>(46, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'currentItem'
        QtMocHelpers::PropertyData<Onboarding*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'currentText'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'additionalDataComponent'
        QtMocHelpers::PropertyData<QQmlComponent*>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(53, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(54, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(55, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(56, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
        // property 'padding'
        QtMocHelpers::PropertyData<qreal>(57, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'blur'
        QtMocHelpers::PropertyData<qreal>(58, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'blurMax'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'hasNextItem'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
        // property 'hasPreviousItem'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<Onboarding, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Onboarding::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10OnboardingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10OnboardingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10OnboardingE_t>.metaTypes,
    nullptr
} };

void Onboarding::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Onboarding *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isSourceChanged(); break;
        case 1: _t->sourceGroupsChanged(); break;
        case 2: _t->groupsChanged(); break;
        case 3: _t->textsChanged(); break;
        case 4: _t->additionalDataChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->aboutToShow(); break;
        case 7: _t->hide(); break;
        case 8: _t->activeChanged(); break;
        case 9: _t->sourceChanged(); break;
        case 10: _t->currentIndexChanged(); break;
        case 11: _t->currentItemChanged(); break;
        case 12: _t->currentTextChanged(); break;
        case 13: _t->additionalDataComponentChanged(); break;
        case 14: _t->geometryChanged(); break;
        case 15: _t->paddingChanged(); break;
        case 16: _t->blurChanged(); break;
        case 17: _t->blurMaxChanged(); break;
        case 18: _t->navigationChanged(); break;
        case 19: _t->aboutToStart(); break;
        case 20: _t->finished(); break;
        case 21: _t->start(); break;
        case 22: _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->stop(); break;
        case 24: _t->next(); break;
        case 25: _t->previous(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::isSourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::sourceGroupsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::groupsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::textsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::additionalDataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::aboutToShow, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::hide, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::activeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::sourceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::currentIndexChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::currentItemChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::currentTextChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::additionalDataComponentChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::geometryChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::paddingChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::blurChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::blurMaxChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::navigationChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::aboutToStart, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Onboarding::*)()>(_a, &Onboarding::finished, 20))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Onboarding* >(); break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 9:
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isSource(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->sourceGroups(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->groups(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->texts(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->additionalData(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 6: *reinterpret_cast<QQuickItem**>(_v) = _t->target(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->sequence(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 9: *reinterpret_cast<QQuickItem**>(_v) = _t->source(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 11: *reinterpret_cast<Onboarding**>(_v) = _t->currentItem(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->currentText(); break;
        case 13: *reinterpret_cast<QQmlComponent**>(_v) = _t->additionalDataComponent(); break;
        case 14: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 15: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        case 16: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 18: *reinterpret_cast<qreal*>(_v) = _t->padding(); break;
        case 19: *reinterpret_cast<qreal*>(_v) = _t->blur(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->blurMax(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->hasNextItem(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->hasPreviousItem(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIsSource(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSourceGroups(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setGroups(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setTexts(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setAdditionalData(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 5: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setAdditionalDataComponent(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 18: _t->setPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 19: _t->setBlur(*reinterpret_cast<qreal*>(_v)); break;
        case 20: _t->setBlurMax(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Onboarding::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Onboarding::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10OnboardingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Onboarding::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Onboarding::isSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Onboarding::sourceGroupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Onboarding::groupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Onboarding::textsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Onboarding::additionalDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Onboarding::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Onboarding::aboutToShow()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Onboarding::hide()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Onboarding::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Onboarding::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Onboarding::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Onboarding::currentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Onboarding::currentTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Onboarding::additionalDataComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Onboarding::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Onboarding::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Onboarding::blurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Onboarding::blurMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Onboarding::navigationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Onboarding::aboutToStart()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Onboarding::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
